#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    init();
}

MainWindow::~MainWindow()
{
    delete ui;
}
void MainWindow::init(){

#ifdef Q_OS_LINUX
    QString settingsDir = QString(getenv("HOME")) + "/.wz2100launcher";
    QDir dir(settingsDir);
    if(!dir.exists()) {
        dir.mkpath(settingsDir);
    }
#endif
    Settings *settings = new Settings();
    GameManager *gameManager = new GameManager();
    if(!settings->loadSettings()) {
        Settings::warzonePath = gameManager->findWarzone();
        Settings::modPath = gameManager->findModPath();
        Settings::dataPath = gameManager->findDataPath();
    }

    if(Settings::warzonePath.length() == 0 || Settings::modPath.length() == 0 || Settings::dataPath.length() == 0 || !gameManager->validBinaryPath()){ //setting may be out of date so check if it still exists
        Settings::warzonePath = gameManager->findWarzone();
        Settings::modPath = gameManager->findModPath();
        Settings::dataPath = gameManager->findDataPath();
        //show settings if warzone was not found and let the user find it
        if(Settings::warzonePath.length() == 0 || Settings::modPath.length() == 0 || Settings::dataPath.length() == 0){
            showSettings();
        }
    }
    delete gameManager;
    delete settings;
}
void MainWindow::showSettings(){
    SettingsDialog *settingsDialog = new SettingsDialog(this);
    settingsDialog->exec();
    delete settingsDialog;
}
void MainWindow::on_startGameButton_clicked()
{
    Settings *settings = new Settings();
    GameManager *gm = new GameManager();

    settings->saveSettings();
    bool gameStarted = gm->startGame(settings->getProfile(Settings::selectedProfile));
    delete settings;
    delete gm;

    if(gameStarted){
        this->close();
    }
    else{
        QMessageBox::information(this,"Failed","Warzone Failed to start",QMessageBox::Ok,QMessageBox::NoButton);
    }
}

void MainWindow::on_settingsButton_clicked()
{
    showSettings();
}

void MainWindow::on_modButton_clicked()
{
    ModProfileWindow *modProfileWindow = new ModProfileWindow(this);
    if(modProfileWindow->exec() == ModProfileWindow::Accepted){
        Settings::selectedProfile = modProfileWindow->getSelectedProfile();
        Settings *settings = new Settings();
        settings->saveSettings();
        delete settings;
    }
    delete modProfileWindow;
}

void MainWindow::on_websiteButton_clicked()
{
    QDesktopServices::openUrl(QUrl("http://www.wz2100.net"));
}

void MainWindow::on_exitButton_clicked()
{
    this->close();
}

void MainWindow::on_creditsButton_clicked()
{
    CreditsDialog *creditsDialog = new CreditsDialog(this);
    creditsDialog->exec();
    delete creditsDialog;
}
