#include "modprofilewindow.h"
#include "ui_modprofilewindow.h"

ModProfileWindow::ModProfileWindow(QWidget *parent) :
    QDialog(parent),
    m_ui(new Ui::ModProfileWindow)
{
    m_ui->setupUi(this);
    init();
}

ModProfileWindow::~ModProfileWindow()
{
    delete m_ui;
}

void ModProfileWindow::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        m_ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
void ModProfileWindow::init(){
    for(int index = 0;index < Settings::modProfiles.size();index++){
        ModProfile profile = Settings::modProfiles.at(index);
        QListWidgetItem *item;

        if(profile.getProfileName() == Settings::selectedProfile){
            item = new QListWidgetItem(QIcon(":/icons/check.png"),profile.getProfileName(),m_ui->modProfiles,0);
        }
        else{
            item = new QListWidgetItem(profile.getProfileName(),m_ui->modProfiles,0);;
        }
        this->m_ui->modProfiles->addItem(item);
    }
}
void ModProfileWindow::on_cancelButton_clicked()
{
    this->reject();
}

void ModProfileWindow::on_modProfiles_itemSelectionChanged()
{
    this->m_ui->deleteButton->setEnabled(true);
    this->m_ui->editButton->setEnabled(true);
    this->m_ui->selectButton->setEnabled(true);
    this->m_ui->loadOrderButton->setEnabled(true);
}

void ModProfileWindow::on_newButton_clicked()
{
    ModProfile profile;
    ModManager *modManager = new ModManager(this,true,profile);
    if(modManager->exec() == ModManager::Accepted){
        this->m_ui->modProfiles->addItem(modManager->getProfileName());
    }
    delete modManager;
}


void ModProfileWindow::on_selectButton_clicked()
{
    selectProfile();
}
void ModProfileWindow::selectProfile(){
    for(int index = 0;index < m_ui->modProfiles->count();index++){
        m_ui->modProfiles->item(index)->setIcon(QIcon());
    }
    m_ui->modProfiles->currentItem()->setIcon(QIcon(":/icons/check.png"));
    this->selectedProfile = m_ui->modProfiles->currentItem()->text();
}

QString ModProfileWindow::getSelectedProfile(){
    return this->selectedProfile;
}
void ModProfileWindow::on_editButton_clicked()
{
    ModProfile profile;
    int itemIndex = -1;
    for(int index = 0;index < Settings::modProfiles.size();index++){
        profile = Settings::modProfiles.at(index);
        if(profile.getProfileName() == m_ui->modProfiles->currentItem()->text()){
            itemIndex = index;
            index = Settings::modProfiles.size();
        }
    }
    ModManager *modManager = new ModManager(this,false,profile);
    if(modManager->exec() == ModManager::Accepted){
        QListWidgetItem *item = m_ui->modProfiles->item(itemIndex);
        item->setText(modManager->getProfileName());
    }
    delete modManager;
}

void ModProfileWindow::on_deleteButton_clicked()
{
    if(QMessageBox::question(this,"Confirm deletion","Are you sure you want to remove this profile?",QMessageBox::Yes,QMessageBox::No) == QMessageBox::Yes){
        Settings *settings = new Settings();
        settings->removeProfile(m_ui->modProfiles->currentItem()->text());
        m_ui->modProfiles->takeItem(m_ui->modProfiles->currentIndex().row());
        delete settings;
        if(m_ui->modProfiles->count() == 0){
            this->m_ui->deleteButton->setEnabled(false);
            this->m_ui->editButton->setEnabled(false);
            this->m_ui->selectButton->setEnabled(false);
            this->m_ui->loadOrderButton->setEnabled(false);
        }
    }

}

void ModProfileWindow::on_loadOrderButton_clicked()
{
    ModOrderWindow *orderWindow = new ModOrderWindow();

    Settings *settings = new Settings();
    orderWindow->setProfile(settings->getProfile(m_ui->modProfiles->currentItem()->text()));
    delete settings;

    orderWindow->exec();

    delete orderWindow;
}

void ModProfileWindow::on_installButton_clicked()
{
    InstallModWindow *installWindow = new InstallModWindow();
    installWindow->exec();
    delete installWindow;
}

void ModProfileWindow::on_okButton_clicked()
{
    this->accept();
}

void ModProfileWindow::on_modProfiles_itemDoubleClicked(QListWidgetItem* item)
{
    selectProfile();
}
